<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Tiếng Việt [VN]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=437
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Tiếng Việt';
$lang_info['country'] = 'Việt Nam';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'vn';
$lang_info['zero_plural'] = true;

$lang['%d Kb'] = '%d Kb';
$lang['%d album updated'] = '%d đề mục đã được cập nhật';
$lang['%d albums updated'] = '%d đề mục đã được cập nhật';
$lang['%d comment to validate'] = '%d lời bình cần xác nhận';
$lang['%d comments to validate'] = '%d lời bình cần xác nhận';
$lang['%d new comment'] = '%d lời bình mới';
$lang['%d new comments'] = '%d lời bình mới';
$lang['%d comment'] = '%d lời bình';
$lang['%d comments'] = '%d lời bình';
$lang['%d hit'] = '%d lần xem';
$lang['%d hits'] = '%d lần xem';
$lang['%d new photo'] = '%d hình mới';
$lang['%d new photos'] = '%d hình mới';
$lang['%d new user'] = '%d thành viên mới';
$lang['%d new users'] = '%d thành viên mới';
$lang['About'] = 'Thông tin về Piwgo';
$lang['All tags'] = 'Tất cả các tags';
$lang['Any tag'] = 'Tất cả các tag';
$lang['At least one listed rule must be satisfied.'] = 'Ít nhất một điều khoản nêu trên phải được đáp ứng.';
$lang['At least one tag must match'] = 'Ít nhất phải có một tag trùng nhau';
$lang['Author'] = 'Tác giả';
$lang['Albums'] = 'Đề mục';
$lang['Album'] = 'Đề mục';
$lang['Close this window'] = 'Đóng';
$lang['Complete RSS feed (photos, comments)'] = 'Bản RSS feed đầy đủ (gồm hình ảnh và lời bình)';
$lang['Confirm Password'] = 'Xác nhận lại mật khẩu';
$lang['Connection settings'] = 'Thiết lập cài đặt';
$lang['Login'] = 'Đăng nhập';
$lang['Contact webmaster'] = 'Liên hệ với Quản trị';
$lang['Create a new account'] = 'Tạo tài khoản mới';
$lang['Created on'] = 'Khởi tạo vào';
$lang['Creation date'] = 'Ngày khởi tạo';
$lang['Current password is wrong'] = 'Mật khởi hiện tại bị sai';
$lang['Dimensions'] = 'Độ phân giải';
$lang['Display'] = 'Hiển thị';
$lang['Each listed rule must be satisfied.'] = 'Mỗi điều khoản nêu trên phải được đáp ứng.';
$lang['Email address'] = 'Địa chỉ email';
$lang['Enter your personnal informations'] = 'Nhập thông tin của bạn';
$lang['Error sending email'] = 'Lỗi gởi email';
$lang['File name'] = 'Tên file';
$lang['File'] = 'Tệp tin';
$lang['Filesize'] = 'Kích thước file';
$lang['Filter and display'] = 'Lọc và hiển thị ảnh';
$lang['Filter'] = 'Lọc';
$lang['Forgot your password?'] = 'Bạn quên mật khẩu?';
$lang['Go through the gallery as a visitor'] = 'Xem gallery như một khách thăm quan';
$lang['Help'] = 'Trợ giúp';
$lang['Identification'] = 'Định danh';
$lang['Photos only RSS feed'] = 'Chỉ hiện hình ảnh trên RSS feed';
$lang['Keyword'] = 'Từ khoá';
$lang['Links'] = 'Liên kết';
$lang['N/A'] = 'Không có';
$lang['New on %s'] = 'hình mới ở %s';
$lang['New password confirmation does not correspond'] = 'Xác nhận mật khẩu mới không được phản hồi';
$lang['Notification'] = 'Thông báo';
$lang['Number of items'] = 'Số lượng hình';
$lang['Original dimensions'] = 'Độ phân giải gốc';
$lang['Password forgotten'] = 'Quên mật khẩu';
$lang['Password'] = 'Mật khẩu';
$lang['Post date'] = 'Ngày gởi hình';
$lang['Posted on'] = 'Gởi vào';
$lang['Profile'] = 'Hồ sơ';
$lang['Quick connect'] = 'Kết nối nhanh';
$lang['RSS feed'] = 'Bản tin RSS';
$lang['Register'] = 'Đăng ký';
$lang['Registration'] = 'Mục đăng ký';
$lang['Related tags'] = 'Tag liên quan';
$lang['Reset'] = 'Làm lại';
$lang['Retrieve password'] = 'Nhận lại mật khẩu';
$lang['Search rules'] = 'Điều khoản tìm kiếm';
$lang['Search tags'] = 'Tag tìm kiếm';
$lang['Search'] = 'Tìm kiếm';
$lang['display available tags'] = 'Xem các tag được dùng';
$lang['Since'] = 'Từ';
$lang['Sort by'] = 'Sắp xếp theo';
$lang['Sort order'] = 'Vị trí sắp xếp';
$lang['Tag'] = 'Thẻ';
$lang['Tags'] = 'Thẻ';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'Bản thông báo RSS feed cung cấp thông báo về tin tức và cập nhật trên trang này bao gồm: hình ảnh mới, đề mục được cập nhật và lời bình mới. Hãy sử dụng trình đọc RSS Feed.';
$lang['Unknown feed identifier'] = 'Nguồn cung cấp tin không xác nhận';
$lang['User comments'] = 'Bình luận của thành viên';
$lang['Username'] = 'Tên đăng nhập';
$lang['Visits'] = 'Thăm quan';
$lang['Webmaster'] = 'Quản trị';
$lang['Week %d'] = 'Tuần %d';
$lang['About Piwigo'] = 'Thông tin về Piwigo';
$lang['You are not authorized to access the requested page'] = 'Bạn không được phép truy cập vào trang này';
$lang['add to caddie'] = 'thêm vào caddie';
$lang['add this photo to your favorites'] = 'thêm hình này vào danh sách ưa thích của mình';
$lang['Administration'] = 'Điều hành viên';
$lang['all'] = 'tất cả';
$lang['ascending'] = 'từ dưới lên';
$lang['author(s) : %s'] = 'tác giả: %s';
$lang['Expand all albums'] = 'Mở rộng các đề mục';
$lang['posted after %s (%s)'] = 'gởi sau %s (%s)';
$lang['posted before %s (%s)'] = 'gởi trước %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'gởi vào giữa %s (%s) và %s (%s)';
$lang['posted on %s'] = 'gởi vào %s';
$lang['Best rated'] = 'Hình được đánh giá tốt nhất';
$lang['display best rated photos'] = 'hiển thị các hình được đánh giá tốt nhất';
$lang['caddie'] = 'caddie';
$lang['Calendar'] = 'Xem hình theo lịch';
$lang['All'] = 'Tất cả';
$lang['display each day with photos, month per month'] = 'hiển thị mỗi ngày kèm hình ảnh, tháng trên tháng';
$lang['View'] = 'Xem';
$lang['chronology_monthly_calendar'] = 'Lịch hằng tháng';
$lang['chronology_monthly_list'] = 'Danh sách hằng tháng';
$lang['chronology_weekly_list'] = 'Danh sách hằng tuần';
$lang['Click here if your browser does not automatically forward you'] = 'Click vào đây nếu trình duyệt web không tự động chuyển trang';
$lang['comment date'] = 'ngày bình luận';
$lang['Comment'] = 'Bình luận';
$lang['Your comment has been registered'] = 'Lời bình của bạn đã được đăng ký';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Hệ thống bảo vệ DOS: vui lòng đợi trong giây lát trước khi gởi lời bình khác';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Lời bình của bạn KHÔNG được đăng ký vì nó không đáp ứng được điều khoản xác nhận';
$lang['An administrator must authorize your comment before it is visible.'] = 'Lời bình của bạn phải được quản trị xác nhận trước khi nó hiển thị trên gallery.';
$lang['This login is already used by another user'] = 'Tài khoản đã được đăng ký trước đây';
$lang['Comments'] = 'Lời bình';
$lang['Add a comment'] = 'Thêm lời bình';
$lang['created after %s (%s)'] = 'đã tạo sau %s (%s)';
$lang['created before %s (%s)'] = 'đã tạo trước %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'đã tạo giữa %s (%s) và %s (%s)';
$lang['created on %s'] = 'đã tạo vào %s';
$lang['Customize'] = 'Tuỳ chọn';
$lang['Your Gallery Customization'] = 'Tuỳ chọn cho Gallery của bạn ';
$lang['day'][0] = 'Chủ Nhật';
$lang['day'][1] = 'Thứ Hai';
$lang['day'][2] = 'Thứ Ba';
$lang['day'][3] = 'Thứ Tư';
$lang['day'][4] = 'Thứ Năm';
$lang['day'][5] = 'Thứ Sáu';
$lang['day'][6] = 'Thứ Bảy';
$lang['Default'] = 'Mặc định';
$lang['delete this photo from your favorites'] = 'xoá hình này từ danh sách ưa thích của bạn';
$lang['Delete'] = 'Xoá bỏ';
$lang['descending'] = 'từ trên xuống';
$lang['download'] = 'tải về';
$lang['download this file'] = 'tải về file này';
$lang['edit'] = 'biên tập';
$lang['wrong date'] = 'sai ngày tháng';
$lang['excluded'] = 'bao gồm';
$lang['Your favorites'] = 'Mục ưa thích của tôi';
$lang['display your favorites photos'] = 'hiển thị những hình ưa thích của tôi';
$lang['Favorites'] = 'Danh sách ưa thích';
$lang['First'] = 'Đầu tiên';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Gallery đã tạm khoá để bảo trì định kỳ. Mời bạn ghé lại sau.';
$lang['Page generated in'] = 'Trang được tạo trong vòng';
$lang['guest'] = 'khách';
$lang['Hello'] = 'Xin chào';
$lang['available for administrators only'] = 'chỉ dành cho Quản trị';
$lang['display this album'] = 'hiện hình này ở phía trên của đề mục';
$lang['display last user comments'] = 'Xem bình luận gần nhất';
$lang['customize the appareance of the gallery'] = 'tuỳ chọn giao diện hiển thị của gallery';
$lang['search'] = 'tìm kiếm';
$lang['Home'] = 'Trang chủ';
$lang['in this album'] = 'trong mục này';
$lang['in %d sub-album'] = 'trong %d mục nhỏ';
$lang['in %d sub-albums'] = 'trong %d các mục nhỏ';
$lang['included'] = 'bao gồm';
$lang['Invalid password!'] = 'Sai mật khẩu!';
$lang['Language']='Ngôn ngữ';
$lang['last %d days'] = '%d ngày cuối';
$lang['Last'] = 'Cuối';
$lang['Logout'] = 'Thoát';
$lang['E-mail address'] = 'Địa chỉ email';
$lang['obligatory'] = 'Phần bắt buộc';
$lang['Maximum photo height'] = 'Chiều cao tối đa của hình';
$lang['Maximum height must be a number superior to 50'] = 'Chiều cao tối đa của hình phải trên 50 pixel';
$lang['Maximum photo width'] = 'Chiều rộng tối đa của hình';
$lang['Maximum width must be a number superior to 50'] = 'Chiều rộng tối đa của hình phải trên 50 pixel';
$lang['display a calendar by creation date'] = 'hiển thị lịch theo ngày gởi hình';
$lang['display all photos in all sub-albums'] = 'hiển thị mọi thành phần có trong tất cả mục nhỏ';
$lang['return to normal view mode'] = 'chuyện lại chế độ xem hình bình thường';
$lang['display a calendar by posted date'] = 'hiển thị lịch theo ngày gởi hình';
$lang['month'][10] = 'Tháng Mười';
$lang['month'][11] = 'Tháng Mười Một';
$lang['month'][12] = 'Tháng Mười Hai';
$lang['month'][1] = 'Tháng Giêng';
$lang['month'][2] = 'Tháng Hai';
$lang['month'][3] = 'Tháng Ba';
$lang['month'][4] = 'Tháng Tư';
$lang['month'][5] = 'Tháng Năm';
$lang['month'][6] = 'Tháng Sáu';
$lang['month'][7] = 'Tháng Bảy';
$lang['month'][8] = 'Tháng Tám';
$lang['month'][9] = 'Tháng Chín';
$lang['Most visited'] = 'Hình được xem nhiều nhất';
$lang['display most visited photos'] = 'hiển thị những hình được xem nhiều nhất';
$lang['Unknown identifier'] = 'Định danh không xác định';
$lang['New password'] = 'Mật khẩu mới';
$lang['Rate this photo'] = 'Đánh giá hình này';
$lang['Next'] = 'Tiếp theo';
$lang['no rate'] = 'không có đánh giá';
$lang['Photos posted within the last %d day.'] = 'Thành phần được gởi trong vòng %d ngày cuối.';
$lang['Photos posted within the last %d days.'] = 'Các thành phần được gởi trong %d ngày cuối.';
$lang['password updated'] = 'mật khẩu đã được cập nhật';
$lang['Recent period must be a positive integer value'] = 'Chu kỳ gần đây phải có giá trị là số nguyên dương';
/* DEPRECATED USED IN comments.php FOR image_id ? */ $lang['photo'] = 'hình ảnh';
$lang['Click on the photo to see it in high definition'] = 'Click lên hình để xem ở định dạng cao';
$lang['Show file metadata'] = 'Hiển thị metadata của hình';
$lang['Powered by'] = 'Sản phẩm của';
$lang['Preferences'] = 'Tuỳ chọn thêm';
$lang['Previous'] = 'Trước';
$lang['Random photos'] = 'Hình ngẫu nhiên';
$lang['display a set of random photos'] = 'hiển thị một bộ các hình ngẫu nhiên';
$lang['Recent albums'] = 'Các đề mục gần đây';
$lang['display recently updated albums'] = 'hiển thị các đề mục gần đây';
$lang['Recent period'] = 'Chu kỳ gần đây';
$lang['Recent photos'] = 'Các hình gần đây';
$lang['display most recent photos'] = 'hiển thị các hình gần đây nhất';
$lang['Redirection...'] = 'Chuyển trang...';
$lang['Please, enter a login'] = 'Vui lòng nhập tên tài khoản';
$lang['login mustn\'t end with a space character'] = 'tên tài khoản không được có ký tự trắng sau cùng';
$lang['login mustn\'t start with a space character'] = 'tên tài khoản không được có ký tự trắng đầu tiên';
$lang['this login is already used'] = 'tài khoản này đã được đăng ký trước đó';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'địa chỉ email phải có dạng xxx@yyy.eee (ví dụ : jack@altern.org)';
$lang['please enter your password again'] = 'vui lòng nhập lại mật khẩu';
$lang['Auto login'] = 'Tự động đăng nhập';
$lang['remove this tag from the list'] = 'bỏ tag này khỏi danh sách';
$lang['representative'] = 'đại diện';
$lang['Search for Author'] = 'Tìm kiếm theo tác giả';
$lang['Search in albums'] = 'Tìm kiếm trong các đề mục';
$lang['Search by Date'] = 'Tìm kiếm theo ngày tháng';
$lang['Date'] = 'Ngày tháng';
$lang['End-Date'] = 'Ngày kết thúc';
$lang['Kind of date'] = 'Kiểu ngày tháng';
$lang['Search for words'] = 'Tìm kiếm theo từ';
$lang['Search for all terms'] = 'Tìm kiếm tất cả các mục ';
$lang['Search for any terms'] = 'Tìm kiếm mọi mục';
$lang['Empty query. No criteria has been entered.'] = 'Truy vấn xác định. Không có từ khoá nào được nhập';
$lang['Search Options'] = 'Tuỳ chọn tìm kiếm';
$lang['Search results'] = 'Kết quả tìm kiếm';
$lang['Search in sub-albums'] = 'Tìm kiếm trong các mục nhỏ';
$lang['searched words : %s'] = 'những từ khoá được tìm kiếm : %s';
$lang['Contact'] = 'Liên hệ';
$lang['set as album representative'] = 'đặt như là một đề mục đại diện';
$lang['Show number of comments'] = 'Hiện số lần hình luận';
$lang['Show number of hits'] = 'Hiện số lần xem';
$lang['slideshow'] = 'trình chiéu';
$lang['stop the slideshow'] = 'dừng trình chiếu';
$lang['Specials'] = 'Đặc biệt';
$lang['SQL queries in'] = 'Truy vấn SQL trong';
$lang['display only recently posted photos'] = 'chỉ hiển thị những hình vừa được gởi';
$lang['return to the display of all photos'] = 'trở lại hiển thị tất cả các hình';
$lang['the beginning'] = 'bắt đầu';
$lang['Interface theme'] = 'Giao diện';
$lang['Thumbnails'] = 'Hình nhỏ';
$lang['Menu'] = 'Trình đơn';
$lang['A comment on your site'] = 'Một lời bình trên trang của bạn';
$lang['today'] = 'hôm nay';
$lang['Update your rating'] = 'Cập nhật xếp hạng của bạn';
$lang['wrong filename'] = 'Sai tên';
$lang['the username must be given'] = 'Phải có tên của thành viên';
$lang['useful when password forgotten'] = 'có ích khi bị mất mật khẩu';
$lang['Quick search'] = 'Tìm kiếm nhanh';
$lang['Connected user: %s'] = 'Thành viên kết nối: %s';
$lang['IP: %s'] = 'Địa chỉ IP: %s';
$lang['Browser: %s'] = 'Trình duyệt: %s';
$lang['Author: %s'] = 'Tác giả: %s';
$lang['Comment: %s'] = 'Bình luận: %s';
$lang['Comment by %s'] = 'Bình luận bởi %s';
$lang['User: %s'] = 'Tài khoản: %s';
$lang['Email: %s'] = 'Địa chỉ email: %s';
$lang['Admin: %s'] = 'Quản trị: %s';
$lang['Registration of %s'] = 'Mục đăng ký của %s';
$lang['Album: %s'] = 'Đề mục: %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Status xấu đối với thành viên đăng thuộc nhóm "khách", sử dụng status mặc định. Thông báo ngay cho Quản trị';
$lang['this email address is already in use'] = 'đã có thành viên sử dụng địa chỉ email này';
$lang['Album results for'] = 'Kết quả đề mục cho';
$lang['Tag results for'] = 'Kết quả tag cho';
$lang['from %s to %s'] = 'từ %s đến %s';
$lang['Play of slideshow'] = 'Bật trình chiếu';
$lang['Pause of slideshow'] = 'Tạm dừng trình chiếu';
$lang['Repeat the slideshow'] = 'Lặp lại trình chiếu';
$lang['Not repeat the slideshow'] = 'Không lặp lại trình chiếu';
$lang['Reduce diaporama speed'] = 'Giảm diaporama speed';
$lang['Accelerate diaporama speed'] = 'Tăng diaporama speed';
$lang['Submit'] = 'Đăng ký';
$lang['Yes'] = 'Có';
$lang['No'] = 'Không';
$lang['%d photo']='%d hình';
$lang['%d photos']='%d hình';
$lang['%d photo is also linked to current tags'] = '%d hình được liên kết với tag hiện tại';
$lang['%d photos are also linked to current tags'] = '%d hình được liên kết với tag hiện tại';
$lang['display photos linked to this tag'] = 'Chỉ xem những hình liên kết với tag này';
$lang['photos posted during the last %d days'] = 'hình được gởi trong vòng %d ngày cuối';
$lang['Piwigo Help'] = 'Trợ giúp của Piwigo';
$lang['Rank'] = 'Hạng';
$lang['group by letters'] = 'phân nhóm theo ký tự';
$lang['letters'] = 'ký tự';
$lang['cloud'] = 'mây';
$lang['Reset to default values'] = 'Thiết lập lại giá trị mặc định';
$lang['delete all photos from your favorites'] = 'xoá tất cả hình từ danh sách ưa thích';
$lang['Sent by'] = 'Được gởi bởi';
$lang['Are you sure?'] = 'Bạn có chắc không?';
$lang['delete this comment'] = 'xóa bỏ lời bình này';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Cookies đã bị chặn lại hoặc không được trình duyệt web trên  máy bạn hỗ trợ. Bạn phải mở cookie để tiếp tục.';
$lang['edit this comment'] = 'biên tập lại lời bình này';
$lang['Edit a comment'] = 'Biên tập một lời bình';
$lang['(!) This comment requires validation'] = '(!) Lời bình này yêu cầu sự xác nhận';
$lang['Welcome'] = 'Xin chào';
$lang['Welcome to your Piwigo photo gallery!'] = 'Chào mừng bạn đến gallery Piwigo trực tuyến của mình!';
$lang['... or browse your empty gallery'] = '... hoặc duyệt gallery chưa có hình của bạn';
$lang['... or please deactivate this message, I will find my way by myself'] = '... hoặc vui lòng vô hiệu hóa thông điệp này, tôi tự tìm cách giải quyết riêng';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Xin chào %s, gallery Piwigo của bạn hiện tại vẫn chưa có tấm hình nào!';
$lang['I want to add photos'] = 'Tôi muốn thêm hình vào gallery';
$lang['Manage this user comment: %s'] = 'Quản lý lời bình của thành viên này: %s';
$lang['Email address is missing. Please specify an email address.'] = 'Còn thiếu địa chỉ email. Vui lòng cho biết một địa chỉ email.';
$lang['This author modified following comment:'] = 'Tác giả này đã soạn lại lời bình sau:';
$lang['This author removed the comment with id %d'] = 'Tác giả này đã xóa bỏ lời bình có ID là %d';
$lang['validate this comment'] = 'xác nhận lời bình này';
$lang['show tag cloud'] = 'hiển thị thẻ mây';
$lang['html tags are not allowed in login'] = 'thẻ html không được phép dùng để đăng nhập';
$lang['The number of photos per page must be a not null scalar'] = 'Số hình trên mỗi trang phải là số nguyên khác 0';
$lang['Number of photos per page'] = 'Số hình trên mỗi trang';
$lang['%d rates'] = '%d hạng';
$lang['Rating score'] = 'Bảng xếp hạng';
$lang['Enter a username or email address'] = 'Nhập tên người dùng hoặc địa chỉ email';
$lang['Invalid username or email'] = 'Tên người dùng hoặc địa chỉ email không hợp lệ';
$lang['Password reset is not allowed for this user'] = 'Không được phép đặt lại mật khẩu cho người dùng này';
$lang['User "%s" has no email address, password reset is not possible'] = 'Người dùng "%s" không có địa chỉ email, nên việc đặt lại mật khẩu là không thể được';
$lang['Someone requested that the password be reset for the following user account:'] = 'Có người yêu cầu đặt lại mật khẩu cho những người dùng sau:';
$lang['Username "%s" on gallery %s'] = 'Người dùng "%s" trên thư viện hình %s';
$lang['To reset your password, visit the following address:'] = 'Để đặt lại mật khẩu, hãy vào những địa chỉ sau:';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Nếu đây là do nhầm lẫn, thì chỉ việc bỏ qua bỏ qua email này và không có việc gì sẽ xảy ra.';
$lang['Password Reset'] = 'Cài đặt lại mật khẩu';
$lang['Check your email for the confirmation link'] = 'Kiểm tra email để nhận liên kết xác nhận';
$lang['Invalid key'] = 'Key không hợp lệ';
$lang['The passwords do not match'] = 'Mật khẩu không trùng';
$lang['Your password has been reset'] = 'Mật khẩu của bạn đã được đặt lại';
$lang['Return to home page'] = 'Trở lại trang chủ';
$lang['Please enter your username or email address.'] = 'Vui lòng nhập tên người dùng và địa chỉ email.';
$lang['You will receive a link to create a new password via email.'] = 'Bạn sẽ nhận được một liên kết để tạo mật khẩu mới qua email.';
$lang['Username or email'] = 'Người dùng hoặc email';
$lang['Change my password'] = 'Đổi mật khẩu của tôi';
$lang['Enter your new password below.'] = 'Nhập mật khẩu mới của bạn ở dưới.';
$lang['Reset Password'] = 'Đặt lại mật khẩu';
$lang['EXIF Metadata'] = 'Lý lịch dữ liệu EXIF';
$lang['IPTC Metadata'] = 'Lý lịch dữ liệu IPTC';

?>